<?php

namespace Drupal\user_menu_avatar\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures size and shape settings of the user menu avatar.
 */
class UserMenuAvatarConfigurationForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
    public function getFormId() {
        return 'user_menu_avatar_settings';
    }

  /**
   * {@inheritdoc}
   */
    protected function getEditableConfigNames() {
        return [
            'user_menu_avatar.user_menu_avatar_settings',
        ];
    }

  /**
   * {@inheritdoc}
   */
    public function buildForm(array $form, FormStateInterface $form_state) {
        
        $config = $this->config('user_menu_avatar.user_menu_avatar_settings');
            
        $avatar_shape_options = array(
            'circle' => t('Circle'),
            'square' => t('Square'),
        );
        
        $form['user_avatar_heading'] = [
            '#type' => 'item',
            '#markup' => t('<h2>Available User Menu Avatar Settings</h2>'),
        ];
        
        $form['avatar_shape_wrapper'] = array(
            '#type' => 'fieldset',
            '#weight' => 0,
            '#attributes' => array(
                'class' => array(
                    'avatar-shape',
                ),
            ),
        );
                
        $form['avatar_shape_wrapper']['avatar_shape'] = array(
            '#type' => 'radios',
            '#title' => t('User Menu Avatar Shape'),
            '#required' => true,
            '#options' => $avatar_shape_options,
            '#description' => t('Choose the shape of the avatar image in the user menu. '),
            '#default_value' => $config->get('avatar_shape') ? : 'circle',
        );
        
        $form['avatar_size_wrapper'] = array(
            '#type' => 'fieldset',
            '#weight' => 1,
            '#attributes' => array(
                'class' => array(
                    'avatar-size',
                ),
            ),
        );
        
        $form['avatar_size_wrapper']['avatar_size'] = array(
            '#type' => 'textfield',
            '#attributes' => array(
                ' type' => 'number',
            ),
            '#title' => t('User Menu Avatar Size (px)'),
            '#required' => true,
            '#description' => t('The size of the User Menu Avatar in "pixels". Applies to both width and height. Numeric value only. '),
            '#maxlength' => 3,
            '#size' => 30,
            '#default_value' => $config->get('avatar_size') ? : '50',
        );
        
        $form['form_info'] = [
            '#type' => 'item',
            '#weight' => 10,
            '#markup' => t('<p>User Menu Avatar uses CSS to position the user_picture. The width and height are set by inline styles on the span element. The border radius only applies if you choose shape circle. The module CSS consists of:</p>
<pre style="background: #f3f3f3;"><code>
    span.user-menu-avatar {
        position: relative;
        display: block;
        padding: 0;
        margin: 0;
        background-repeat: no-repeat;
        background-clip: border-box;
        background-origin: padding-box;
        background-size: cover;
        background-position: center;
    }

    span.user-menu-avatar.circle {
        border-radius: 50%;
    }
    
</code></pre>
            '),
        ];
        
        return parent::buildForm($form, $form_state);
    }

  /**
   * {@inheritdoc}
   */
    public function submitForm(array &$form, FormStateInterface $form_state) {
        $values = $form_state->getValues();
        
        $this->config('user_menu_avatar.user_menu_avatar_settings')
            ->set('avatar_shape', $values['avatar_shape']);
        $this->config('user_menu_avatar.user_menu_avatar_settings')
            ->set('avatar_size', $values['avatar_size'])
            ->save();
        parent::submitForm($form, $form_state);
        
    }

}